@@ -79,7 +79,7 @@ if(min(pars1) < 0 || pars1[1] <= pars1[2]) { loglik = -Inf } else
 s1 = sprintf('Parameters: %f %f %f',pars1[1],pars1[2],pars1[3])
 if(ddep == 5) {s1 = sprintf('%s %f',s1,pars1[4])}
 s2 = sprintf(', Loglikelihood: %f',loglik)
-cat(s1,s2,"\n")
+cat(s1,s2,"\n",sep = "")
 flush.console()
 
 return(loglik)
